@@ -39,9 +39,14 @@ DesktopPortal::DesktopPortal(QObject *parent)
     , m_print(new PrintPortal(this))
 #if SCREENCAST_ENABLED
     , m_screenCast(new ScreenCastPortal(this))
+    , m_remoteDesktop(new RemoteDesktopPortal(this))
 #endif
     , m_screenshot(new ScreenshotPortal(this))
+    , m_settings(new SettingsPortal(this))
 {
+#if SCREENCAST_ENABLED
+    WaylandIntegration::init();
+#endif
 }
 
 DesktopPortal::~DesktopPortal()
